@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Serializer::NTriples - NTriples Serializer.
+RDF::Trine::Serializer::NTriples - N-Triples Serializer.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::NTriples version 0.114_04
+This document describes RDF::Trine::Serializer::NTriples version 0.118_01
 
 =head1 SYNOPSIS
 
@@ -16,7 +16,7 @@ This document describes RDF::Trine::Serializer::NTriples version 0.114_04
 
 =head1 DESCRIPTION
 
-The RDF::Trine::Serializer::Turtle class provides an API for serializing RDF
+The RDF::Trine::Serializer::NTriples class provides an API for serializing RDF
 graphs to the N-Triples syntax.
 
 =head1 METHODS
@@ -45,7 +45,11 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.114_04';
+	$VERSION	= '0.118_01';
+	$RDF::Trine::Serializer::serializer_names{ 'ntriples' }	= __PACKAGE__;
+	foreach my $type (qw(text/plain)) {
+		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
+	}
 }
 
 ######################################################################
@@ -65,7 +69,7 @@ sub new {
 
 =item C<< serialize_model_to_file ( $fh, $model ) >>
 
-Serializes the C<$model> to NTriples, printing the results to the supplied
+Serializes the C<$model> to N-Triples, printing the results to the supplied
 filehandle C<<$fh>>.
 
 =cut
@@ -82,7 +86,7 @@ sub serialize_model_to_file {
 
 =item C<< serialize_model_to_string ( $model ) >>
 
-Serializes the C<$model> to NTriples, returning the result as a string.
+Serializes the C<$model> to N-Triples, returning the result as a string.
 
 =cut
 
@@ -100,7 +104,7 @@ sub serialize_model_to_string {
 
 =item C<< serialize_iterator_to_file ( $file, $iter ) >>
 
-Serializes the iterator to NTriples, printing the results to the supplied
+Serializes the iterator to N-Triples, printing the results to the supplied
 filehandle C<<$fh>>.
 
 =cut
@@ -114,15 +118,9 @@ sub serialize_iterator_to_file {
 	}
 }
 
-sub _statement_as_string {
-	my $self	= shift;
-	my $st		= shift;
-	return join(' ', map { $_->as_ntriples } $st->nodes) . " .\n";
-}
-
 =item C<< serialize_iterator_to_string ( $iter ) >>
 
-Serializes the iterator to NTriples, returning the result as a string.
+Serializes the iterator to N-Triples, returning the result as a string.
 
 =cut
 
@@ -155,6 +153,12 @@ sub _serialize_bounded_description {
 	return $string;
 }
 
+sub _statement_as_string {
+	my $self	= shift;
+	my $st		= shift;
+	return join(' ', map { $_->as_ntriples } $st->nodes) . " .\n";
+}
+
 1;
 
 __END__
