@@ -61,7 +61,11 @@ our @ISA = qw();
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.114';
+	$VERSION	= '0.118_01';
+	$RDF::Trine::Serializer::serializer_names{ 'ntriples-canonical' }	= __PACKAGE__;
+# 	foreach my $type (qw(text/plain)) {
+# 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
+# 	}
 }
 
 ######################################################################
