@@ -7,7 +7,7 @@ RDF::Trine::Serializer::RDFJSON - RDF/JSON Serializer.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::RDF/JSON version 0.114
+This document describes RDF::Trine::Serializer::RDF/JSON version 0.118_01
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,11 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.114';
+	$VERSION	= '0.118_01';
+	$RDF::Trine::Serializer::serializer_names{ 'rdfjson' }	= __PACKAGE__;
+	foreach my $type (qw(application/json application/x-rdf+json)) {
+		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
+	}
 }
 
 ######################################################################
