@@ -7,12 +7,13 @@ RDF::Trine::Serializer::RDFXML - RDF/XML Serializer.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::RDFXML version 0.114_04
+This document describes RDF::Trine::Serializer::RDFXML version 0.118_01
 
 =head1 SYNOPSIS
 
  use RDF::Trine::Serializer::RDFXML;
- my $serializer	= RDF::Trine::Serializer::RDFXML->new();
+ my $serializer	= RDF::Trine::Serializer::RDFXML->new( namespaces => { ex => 'http://example/' } );
+ print $serializer->serialize_model_to_string($model);
 
 =head1 DESCRIPTION
 
@@ -45,21 +46,30 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.114_04';
+	$VERSION	= '0.118_01';
+	$RDF::Trine::Serializer::serializer_names{ 'rdfxml' }	= __PACKAGE__;
+	foreach my $type (qw(application/rdf+xml)) {
+		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
+	}
 }
 
 ######################################################################
 
-=item C<< new >>
+=item C<< new ( namespaces => \%namespaces ) >>
 
-Returns a new 
+Returns a new RDF/XML serializer object.
 
 =cut
 
 sub new {
 	my $class	= shift;
 	my %args	= @_;
-	my $self = bless( {}, $class);
+	my $self = bless( { namespaces => { 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' => 'rdf' } }, $class);
+	if (my $ns = $args{namespaces}) {
+		my %ns		= %{ $ns };
+		my %nsmap	= reverse %ns;
+		@{ $self->{namespaces} }{ keys %nsmap }	= values %nsmap;
+	}
 	return $self;
 }
 
@@ -86,16 +96,6 @@ Serializes the C<$model> to RDF/XML, returning the result as a string.
 
 =cut
 
-sub serialize_model_to_string {
-	my $self	= shift;
-	my $model	= shift;
-	my $string	= '';
-	open( my $fh, '>', \$string );
-	$self->serialize_model_to_file( $fh, $model );
-	close($fh);
-	return $string;
-}
-
 =item C<< serialize_iterator_to_file ( $file, $iter ) >>
 
 Serializes the iterator to RDF/XML, printing the results to the supplied
@@ -107,9 +107,13 @@ sub serialize_iterator_to_file {
 	my $self	= shift;
 	my $fh		= shift;
 	my $iter	= shift;
-	print {$fh} qq[<?xml version="1.0" encoding="utf-8"?>\n<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n];
 	
-	my @statements	= $iter->next;
+	my $ns		= $self->_top_xmlns();
+	print {$fh} qq[<?xml version="1.0" encoding="utf-8"?>\n<rdf:RDF $ns>\n];
+	
+	my $st			= $iter->next;
+	my @statements;
+	push(@statements, $st) if blessed($st);
 	while (@statements) {
 		my $st	= shift(@statements);
 		my @samesubj;
@@ -145,7 +149,7 @@ sub _statements_same_subject_as_string {
 	}
 	
 	my $counter	= 1;
-	my %namespaces	= ('http://www.w3.org/1999/02/22-rdf-syntax-ns#' => 'rdf');
+	my %namespaces	= %{ $self->{namespaces} };
 	my $string	= '';
 	foreach my $st (@statements) {
 		my (undef, $p, $o)	= $st->nodes;
@@ -186,10 +190,13 @@ sub _statements_same_subject_as_string {
 	$string	.= qq[</rdf:Description>\n];
 	
 	# rdf namespace is already defined in the <rdf:RDF> tag, so ignore it here
-	delete $namespaces{ 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' };
-	
-	my $namespaces	= join(' ', map { my $ns = $namespaces{$_}; qq[xmlns:${ns}="$_"] } sort { $namespaces{$a} cmp $namespaces{$b} } (keys %namespaces));
-	return qq[<rdf:Description ${namespaces} $id>\n] . $string;
+	my %seen	= %{ $self->{namespaces} };
+	my $ns	= join(' ', map { my $ns = $namespaces{$_}; qq[xmlns:${ns}="$_"] } sort { $namespaces{$a} cmp $namespaces{$b} } grep { not($seen{$_}) } (keys %namespaces));
+	if ($ns) {
+		return qq[<rdf:Description ${ns} $id>\n] . $string;
+	} else {
+		return qq[<rdf:Description $id>\n] . $string;
+	}
 }
 
 =item C<< serialize_iterator_to_string ( $iter ) >>
@@ -198,23 +205,14 @@ Serializes the iterator to RDF/XML, returning the result as a string.
 
 =cut
 
-sub serialize_iterator_to_string {
-	my $self	= shift;
-	my $iter	= shift;
-	my $string	= '';
-	open( my $fh, '>', \$string );
-	$self->serialize_iterator_to_file( $fh, $iter );
-	close($fh);
-	return $string;
-}
-
 sub _serialize_bounded_description {
 	my $self	= shift;
 	my $model	= shift;
 	my $node	= shift;
 	my $seen	= {};
 	
-	my $string	= qq[<?xml version="1.0" encoding="utf-8"?>\n<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n];
+	my $ns		= $self->_top_xmlns();
+	my $string	= qq[<?xml version="1.0" encoding="utf-8"?>\n<rdf:RDF $ns>\n];
 	$string		.= $self->__serialize_bounded_description( $model, $node, $seen );
 	$string	.= qq[</rdf:RDF>\n];
 	return $string;
@@ -244,6 +242,20 @@ sub __serialize_bounded_description {
 	return $string;
 }
 
+sub _top_xmlns {
+	my $self	= shift;
+	my $namespaces	= $self->{namespaces};
+	my @keys		= sort { $namespaces->{$a} cmp $namespaces->{$b} } keys %$namespaces;
+	
+	my @ns;
+	foreach my $v (@keys) {
+		my $k	= $namespaces->{$v};
+		push(@ns, qq[xmlns:$k="$v"]);
+	}
+	my $ns		= join(' ', @ns);
+	return $ns;
+}
+
 1;
 
 __END__
